package com.hungraim.ltc.controller;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.hungraim.ltc.pojo.entity.disable.*;
import com.hungraim.ltc.pojo.vo.disable.DisableExamineInfoVO;
import com.hungraim.ltc.pojo.vo.disable.DisableInfoVO;
import com.hungraim.ltc.pojo.vo.disable.DisableVO;
import com.hungraim.ltc.pojo.vo.disable.DistrictTreeVo;
import com.hungraim.ltc.service.DisableService;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 失能申请Controller
 *
 * @author czz
 */
@RestController
@RequestMapping("/api.apply/disable")
@Slf4j
public class DisableController {

    @Autowired
    private DisableService disableService;

    /**
     * 省市区
     *
     * @param districtLevel 区域级别:1省2地级市3县
     * @param districtCode  上级区域代码
     */
    @RequestMapping("/district")
    public Result<List<ChFndDistrict>> district(String districtLevel, String districtCode) {
        List<ChFndDistrict> districts = disableService.district(districtLevel, districtCode);
        return Result.success(districts);
    }

    /**
     * 获取所有省市区街道数据
     *
     * @return 返回树形结构省市区数据
     */
    @RequestMapping("/allDistrict")
    public Result allDistrict() {
        List<DistrictTreeVo> districtTreeVos = disableService.allDistrict();
        return Result.success(districtTreeVos);
    }

    /**
     * 获取所有省市区街道数据，以树形结构返回
     *
     * @return 返回树形结构省市区数据
     */
    @RequestMapping("/allTreeDistrict")
    public Result allTreeDistrict() {
        List<DistrictTreeVo> districtTreeVos = disableService.getAllDistrictTreeData();
        return Result.success(districtTreeVos);
    }

    /**
     * 查询所有父机构
     */
    @RequestMapping("/fndOrganRoot")
    public Result<List<ChFndOrgan>> fndOrganRoot() {
        List<ChFndOrgan> organs = disableService.fndOrganRoot();
        return Result.success(organs);
    }

    /**
     * 查询所有服务方式
     */
    @RequestMapping("/fndSrvMode")
    public Result<List<ChFndSrvMode>> fndSrvMode() {
        List<ChFndSrvMode> fndSrvModes = disableService.fndSrvModeList();
        return Result.success(fndSrvModes);
    }

    /**
     * 查询机构下所有护理机构
     *
     * @param organId 机构id
     */
    @RequestMapping("/srvOrganList")
    public Result<List<ChSrvOrgan>> srvOrganList(String organId) {
        List<ChSrvOrgan> chFndSrvModes = disableService.srvOrganList(organId);
        return Result.success(chFndSrvModes);
    }

    /**
     * 查询疾病类型
     *
     * @param parDiseTypeId 父疾病类型id 不传值默认查询所有一级疾病类型
     */
    @RequestMapping("/fndDiseaseList")
    public Result<List<ChFndDiseaseType>> fndDiseaseList(String parDiseTypeId) {
        if (StrUtil.isNotBlank(parDiseTypeId)) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        List<ChFndDiseaseType> chFndDiseaseTypes = disableService.fndDiseaseList(parDiseTypeId);
        return Result.success(chFndDiseaseTypes);
    }

    /**
     * 查询所有疾病数据
     */
    @RequestMapping("/fndAllDisease")
    public Result<List<ChFndDiseaseType>> fndAllDisease() {
        List<ChFndDiseaseType> chFndDiseaseTypes = disableService.fndAllDisease();
        return Result.success(chFndDiseaseTypes);
    }

    /**
     * 查询护理机构下所有子机构id
     *
     * @param organId 机构id
     * @return 机构及所有子机构id, 以逗号分隔, 如果没有子机构则只返回机构id
     */
    @RequestMapping("/subsidiariesOrganId")
    public Result<String> subsidiariesOrganId(String organId) {
        if (StrUtil.isBlank(organId)) {
            return Result.failed("organId不能为空!");
        }
        return Result.success(disableService.subsidiariesOrganId(organId));
    }

    /**
     * 失能人员信息列表
     *
     * @param organId            适用机构代码
     * @param districtProvincial 所在省
     * @param districtCity       所在市
     * @param districtArea       所在区域
     * @param realName           失能人员姓名
     * @param certiCode          失能人员身份证号码
     * @param dataFrom           申请来源
     * @param srvOrganName       护理机构名称
     * @param pageNum            当前页
     * @param pageSize           每页几条数据
     * @return 失能人员信息列表
     */
    @RequestMapping("/disableList")
    public Result<IPage<DisableVO>> disableList(String organId, String districtProvincial,
                                                String districtCity, String districtArea,
                                                String realName, String certiCode, String dataFrom,
                                                String srvOrganName, int pageNum, int pageSize) {
        IPage<DisableVO> iPage = disableService.disableList(organId, districtProvincial,
                districtCity, districtArea, realName, certiCode, dataFrom, srvOrganName, pageNum, pageSize);
        return Result.success(iPage);
    }

    /**
     * 失能审核信息详情
     *
     * @param applyId 申请id
     * @return 失能审核信息详情
     */
    @RequestMapping("/disableExamineInfo")
    public Result<DisableExamineInfoVO> disableExamineInfo(String applyId) {
        DisableExamineInfoVO disableExamineInfoVO = disableService.disableExamineInfo(applyId);
        return Result.success(disableExamineInfoVO);
    }

    /**
     * 失能审核
     *
     * @param applyId     申请id
     * @param checkName   审核人
     * @param applyStatus 审核结果
     * @param checkRemark 审核备注
     * @return 失能审核信息详情
     */
    @RequestMapping("/disableExamine")
    public Result disableExamine(String applyId, String checkName, Short applyStatus, String checkRemark) {
        disableService.disableExamine(applyId, checkName, applyStatus, checkRemark);
        return Result.success();
    }

    /**
     * 修改失能申请
     */
    @RequestMapping("/updateDisable")
    public Result updateDisable(ChDisableApply chDisableApply) {
        if (chDisableApply.getApplyId() == null) {
            return Result.failed("请求参数错误");
        }
        disableService.updateDisable(chDisableApply);
        return Result.success();
    }

    /**
     * 新增失能申请
     */
    @RequestMapping("/addDisable")
    public Result addDisable(ChDisableApply chDisableApply) {
        //字段校验
        //所在省市区
        if (StringUtils.isBlank(chDisableApply.getDistrictProvincial()) || StringUtils.isBlank(chDisableApply.getDistrictCity()) || StringUtils.isBlank(chDisableApply.getDistrictArea())) {
            return Result.failed("所在省市不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getRealName())) {
            return Result.failed("申请人姓名不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getCertiCode())) {
            return Result.failed("身份证号码不能为空!");
        }
        if (chDisableApply.getBirthday() == null) {
            return Result.failed("出生年月日不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getGender())) {
            return Result.failed("性别不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getTel())) {
            return Result.failed("手机号不能为空!");
        }
        if (chDisableApply.getRegist() == null) {
            return Result.failed("所在户籍不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getAcptProvincial()) || StringUtils.isBlank(chDisableApply.getAcptCity()) || StringUtils.isBlank(chDisableApply.getAcptArea()) || StringUtils.isBlank(chDisableApply.getAcptStreet()) || StringUtils.isBlank(chDisableApply.getAcptAddress())) {
            return Result.failed("接受评定地址不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getAcptSrvProvincial()) || StringUtils.isBlank(chDisableApply.getAcptSrvCity()) || StringUtils.isBlank(chDisableApply.getAcptSrvArea()) || StringUtils.isBlank(chDisableApply.getAcptSrvStreet()) || StringUtils.isBlank(chDisableApply.getAcptSrvAddress())) {
            return Result.failed("接受服务地址不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getAdressDistrictProvincial()) || StringUtils.isBlank(chDisableApply.getAdressDistrictCity()) || StringUtils.isBlank(chDisableApply.getAdressDistrictCode()) || StringUtils.isBlank(chDisableApply.getStreet()) || StringUtils.isBlank(chDisableApply.getAdressDetail())) {
            return Result.failed("现住址不能为空!");
        }
        if (chDisableApply.getDiseTypeF() == null || chDisableApply.getDiseTypeS() == null) {
            return Result.failed("诊断疾病不能为空!");
        }
        if (chDisableApply.getSrvModeId() == null) {
            return Result.failed("申请服务方式不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getDiseaseDesc())) {
            return Result.failed("疾病描述及诊断不能为空!");
        }
        if (chDisableApply.getMedicalType() == null) {
            return Result.failed("医保类型不能为空!");
        }
        disableService.addDisable(chDisableApply);
        return Result.success();
    }

    /**
     * 查询失能人员信息
     *
     * @param disableInfoId 失能人员id
     */
    @RequestMapping("/getDisableInfo")
    public Result getDisableInfo(String disableInfoId) {
        if (StringUtils.isBlank(disableInfoId)) {
            return Result.failed("请求参数错误");
        }
        DisableInfoVO disableInfoVO = disableService.getDisableInfo(disableInfoId);
        return Result.success(disableInfoVO);
    }

}
