package com.hungraim.ltc.governance.controller;

import com.hungraim.ltc.governance.service.SrvTaskService;
import com.hungraim.ltc.pojo.vo.governance.SrvTaskInfoVO;
import com.hungraim.ltc.pojo.vo.governance.SrvTaskVO;
import com.hungraim.ltc.util.DateUtils;
import com.hungraim.ltc.util.Result;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 服务计划Controller
 *
 * @author czz
 */
@RestController
@RequestMapping("/api.governance/srvTask")
@Slf4j
public class SrvTaskController {

    @Autowired
    private SrvTaskService srvTaskService;

    /**
     * 服务计划、服务计划配置列表
     *
     * @param organId     护理机构id
     * @param disableName 失能人员姓名
     * @param disableTel  失能人员手机号码
     * @param empName     护理人员姓名
     * @param certifNum   护理人员证件号码
     * @param startTime   服务计划开始时间
     * @param endTime     服务计划结束时间
     * @param status      任务状态（服务计划状态）
     * @param modeId      服务方式
     */
    @RequestMapping("/getSrvTaskList")
    public Result<List<SrvTaskVO>> getSrvTaskList(Integer organId, String disableName, String disableTel,
                                                  String empName, String certifNum, String startTime, String endTime,
                                                  String status, String modeId) {
        List<SrvTaskVO> tasks = srvTaskService.getSrvTaskList(organId, disableName, disableTel, empName, certifNum, startTime, endTime, status, modeId);
        return Result.success(tasks);
    }

    /**
     * 查询服务计划制定详情
     *
     * @param taskId 服务计划id
     */
    @RequestMapping("/getSrvTaskInfo")
    public Result<SrvTaskInfoVO> getSrvTaskInfo(String taskId) {
        if (StringUtils.isBlank(taskId)) {
            return Result.failed("taskId不能为空!");
        }
        SrvTaskInfoVO taskInfo = srvTaskService.getSrvTaskInfo(taskId);
        return Result.success(taskInfo);
    }

    /**
     * 新增服务计划
     *
     * @param programId 服务方案id
     * @param srvEmpId  护理人员id
     * @param startTime 服务计划开始时间 yyyy-MM-dd
     * @param endTime   服务计划结束时间 yyyy-MM-dd
     */
    @RequestMapping("/addSrvTask")
    public Result<Object> addSrvTask(Long programId, Long srvEmpId, String startTime, String endTime) {
        if (programId == null) {
            return Result.failed("服务方案id不能为空!");
        }
        if (srvEmpId == null) {
            return Result.failed("护理人员id不能为空!");
        }
        if (StringUtils.isBlank(startTime)) {
            return Result.failed("服务计划开始时间不能为空!");
        }
        if (StringUtils.isBlank(endTime)) {
            return Result.failed("服务计划结束时间不能为空!");
        }
        try {
            srvTaskService.addSrvTask(programId, srvEmpId, DateUtils.strToDate(startTime), DateUtils.strToDate(endTime));
        } catch (RuntimeException e) {
            //添加失败
            return Result.failed(e.getMessage());
        }
        //添加成功
        return Result.success();
    }

    /**
     * 修改服务计划
     *
     * @param taskId    服务计划id
     * @param srvEmpId  护理人员id
     * @param startTime 服务计划开始时间 yyyy-MM-dd
     * @param endTime   服务计划结束时间 yyyy-MM-dd
     */
    @RequestMapping("/updateSrvTask")
    public Result<Object> updateSrvTask(String taskId, Long srvEmpId, String startTime, String endTime) {
        if (taskId == null) {
            return Result.failed("taskId不能为空!");
        }
        if (srvEmpId == null) {
            return Result.failed("护理人员id不能为空!");
        }
        if (StringUtils.isBlank(startTime)) {
            return Result.failed("服务计划开始时间不能为空!");
        }
        if (StringUtils.isBlank(endTime)) {
            return Result.failed("服务计划结束时间不能为空!");
        }
        try {
            srvTaskService.updateSrvTask(taskId, srvEmpId, DateUtils.strToDate(startTime), DateUtils.strToDate(endTime));
        } catch (RuntimeException e) {
            //修改失败
            return Result.failed(e.getMessage());
        }
        //修改成功
        return Result.success();
    }
}
